==> Spire.Xls-13.9.0-py3-none-win_amd64.whl: spire/xls/InteriorArrayWrapper.py <==
from enum import Enum
from plum import dispatch
from typing import TypeVar,Union,Generic,List,Tuple
from spire.xls.common import *
from spire.xls import *
from ctypes import *
import abc

class InteriorArrayWrapper (  XlsObject, IInterior) :
    """

    """
    @property

    def PatternKnownColor(self)->'ExcelColors':
        """

        """
        GetDllLibXls().InteriorArrayWrapper_get_PatternKnownColor.argtypes=[c_void_p]
        GetDllLibXls().InteriorArrayWrapper_get_PatternKnownColor.restype=c_int
        ret = GetDllLibXls().InteriorArrayWrapper_get_PatternKnownColor(self.Ptr)
        objwraped = ExcelColors(ret)
        return objwraped

    @PatternKnownColor.setter
    def PatternKnownColor(self, value:'ExcelColors'):
        GetDllLibXls().InteriorArrayWrapper_set_PatternKnownColor.argtypes=[c_void_p, c_int]
        GetDllLibXls().InteriorArrayWrapper_set_PatternKnownColor(self.Ptr, value.value)

    @property

    def PatternColor(self)->'Color':
        """

        """
        GetDllLibXls().InteriorArrayWrapper_get_PatternColor.argtypes=[c_void_p]
        GetDllLibXls().InteriorArrayWrapper_get_PatternColor.restype=c_void_p
        intPtr = GetDllLibXls().InteriorArrayWrapper_get_PatternColor(self.Ptr)
        ret = None if intPtr==None else Color(intPtr)
        return ret


    @PatternColor.setter
    def PatternColor(self, value:'Color'):
        GetDllLibXls().InteriorArrayWrapper_set_PatternColor.argtypes=[c_void_p, c_void_p]
        GetDllLibXls().InteriorArrayWrapper_set_PatternColor(self.Ptr, value.Ptr)

    @property

    def KnownColor(self)->'ExcelColors':
        """

        """
        GetDllLibXls().InteriorArrayWrapper_get_KnownColor.argtypes=[c_void_p]
        GetDllLibXls().InteriorArrayWrapper_get_KnownColor.restype=c_int
        ret = GetDllLibXls().InteriorArrayWrapper_get_KnownColor(self.Ptr)
        objwraped = ExcelColors(ret)
        return objwraped

    @KnownColor.setter
    def KnownColor(self, value:'ExcelColors'):
        GetDllLibXls().InteriorArrayWrapper_set_KnownColor.argtypes=[c_void_p, c_int]
        GetDllLibXls().InteriorArrayWrapper_set_KnownColor(self.Ptr, value.value)

    @property

    def Color(self)->'Color':
        """

        """
        GetDllLibXls().InteriorArrayWrapper_get_Color.argtypes=[c_void_p]
        GetDllLibXls().InteriorArrayWrapper_get_Color.restype=c_void_p
        intPtr = GetDllLibXls().InteriorArrayWrapper_get_Color(self.Ptr)
        ret = None if intPtr==None else Color(intPtr)
        return ret


    @Color.setter
    def Color(self, value:'Color'):
        GetDllLibXls().InteriorArrayWrapper_set_Color.argtypes=[c_void_p, c_void_p]
        GetDllLibXls().InteriorArrayWrapper_set_Color(self.Ptr, value.Ptr)

    @property

    def Gradient(self)->'ExcelGradient':
        """

        """
        GetDllLibXls().InteriorArrayWrapper_get_Gradient.argtypes=[c_void_p]
        GetDllLibXls().InteriorArrayWrapper_get_Gradient.restype=c_void_p
        intPtr = GetDllLibXls().InteriorArrayWrapper_get_Gradient(self.Ptr)
        ret = None if intPtr==None else ExcelGradient(intPtr)
        return ret


    @property

    def FillPattern(self)->'ExcelPatternType':
        """

        """
        GetDllLibXls().InteriorArrayWrapper_get_FillPattern.argtypes=[c_void_p]
        GetDllLibXls().InteriorArrayWrapper_get_FillPattern.restype=c_int
        ret = GetDllLibXls().InteriorArrayWrapper_get_FillPattern(self.Ptr)
        objwraped = ExcelPatternType(ret)
        return objwraped

    @FillPattern.setter
    def FillPattern(self, value:'ExcelPatternType'):
        GetDllLibXls().InteriorArrayWrapper_set_FillPattern.argtypes=[c_void_p, c_int]
        GetDllLibXls().InteriorArrayWrapper_set_FillPattern(self.Ptr, value.value)

    def BeginUpdate(self):
        """

        """
        GetDllLibXls().InteriorArrayWrapper_BeginUpdate.argtypes=[c_void_p]
        GetDllLibXls().InteriorArrayWrapper_BeginUpdate(self.Ptr)

    def EndUpdate(self):
        """

        """
        GetDllLibXls().InteriorArrayWrapper_EndUpdate.argtypes=[c_void_p]
        GetDllLibXls().InteriorArrayWrapper_EndUpdate(self.Ptr)

==> Spire.Xls-14.4.4-py3-none-win_amd64.whl: spire/xls/InteriorArrayWrapper.py <==
from enum import Enum
from plum import dispatch
from typing import TypeVar,Union,Generic,List,Tuple
from spire.xls.common import *
from spire.xls import *
from ctypes import *
import abc

class InteriorArrayWrapper (  XlsObject, IInterior) :
    """

    """
    @property

    def PatternKnownColor(self)->'ExcelColors':
        """

        """
        GetDllLibXls().InteriorArrayWrapper_get_PatternKnownColor.argtypes=[c_void_p]
        GetDllLibXls().InteriorArrayWrapper_get_PatternKnownColor.restype=c_int
        ret = CallCFunction(GetDllLibXls().InteriorArrayWrapper_get_PatternKnownColor, self.Ptr)
        objwraped = ExcelColors(ret)
        return objwraped

    @PatternKnownColor.setter
    def PatternKnownColor(self, value:'ExcelColors'):
        GetDllLibXls().InteriorArrayWrapper_set_PatternKnownColor.argtypes=[c_void_p, c_int]
        CallCFunction(GetDllLibXls().InteriorArrayWrapper_set_PatternKnownColor, self.Ptr, value.value)

    @property

    def PatternColor(self)->'Color':
        """

        """
        GetDllLibXls().InteriorArrayWrapper_get_PatternColor.argtypes=[c_void_p]
        GetDllLibXls().InteriorArrayWrapper_get_PatternColor.restype=c_void_p
        intPtr = CallCFunction(GetDllLibXls().InteriorArrayWrapper_get_PatternColor, self.Ptr)
        ret = None if intPtr==None else Color(intPtr)
        return ret


    @PatternColor.setter
    def PatternColor(self, value:'Color'):
        GetDllLibXls().InteriorArrayWrapper_set_PatternColor.argtypes=[c_void_p, c_void_p]
        CallCFunction(GetDllLibXls().InteriorArrayWrapper_set_PatternColor, self.Ptr, value.Ptr)

    @property

    def KnownColor(self)->'ExcelColors':
        """

        """
        GetDllLibXls().InteriorArrayWrapper_get_KnownColor.argtypes=[c_void_p]
        GetDllLibXls().InteriorArrayWrapper_get_KnownColor.restype=c_int
        ret = CallCFunction(GetDllLibXls().InteriorArrayWrapper_get_KnownColor, self.Ptr)
        objwraped = ExcelColors(ret)
        return objwraped

    @KnownColor.setter
    def KnownColor(self, value:'ExcelColors'):
        GetDllLibXls().InteriorArrayWrapper_set_KnownColor.argtypes=[c_void_p, c_int]
        CallCFunction(GetDllLibXls().InteriorArrayWrapper_set_KnownColor, self.Ptr, value.value)

    @property

    def Color(self)->'Color':
        """

        """
        GetDllLibXls().InteriorArrayWrapper_get_Color.argtypes=[c_void_p]
        GetDllLibXls().InteriorArrayWrapper_get_Color.restype=c_void_p
        intPtr = CallCFunction(GetDllLibXls().InteriorArrayWrapper_get_Color, self.Ptr)
        ret = None if intPtr==None else Color(intPtr)
        return ret


    @Color.setter
    def Color(self, value:'Color'):
        GetDllLibXls().InteriorArrayWrapper_set_Color.argtypes=[c_void_p, c_void_p]
        CallCFunction(GetDllLibXls().InteriorArrayWrapper_set_Color, self.Ptr, value.Ptr)

    @property

    def Gradient(self)->'ExcelGradient':
        """

        """
        GetDllLibXls().InteriorArrayWrapper_get_Gradient.argtypes=[c_void_p]
        GetDllLibXls().InteriorArrayWrapper_get_Gradient.restype=c_void_p
        intPtr = CallCFunction(GetDllLibXls().InteriorArrayWrapper_get_Gradient, self.Ptr)
        ret = None if intPtr==None else ExcelGradient(intPtr)
        return ret


    @property

    def FillPattern(self)->'ExcelPatternType':
        """

        """
        GetDllLibXls().InteriorArrayWrapper_get_FillPattern.argtypes=[c_void_p]
        GetDllLibXls().InteriorArrayWrapper_get_FillPattern.restype=c_int
        ret = CallCFunction(GetDllLibXls().InteriorArrayWrapper_get_FillPattern, self.Ptr)
        objwraped = ExcelPatternType(ret)
        return objwraped

    @FillPattern.setter
    def FillPattern(self, value:'ExcelPatternType'):
        GetDllLibXls().InteriorArrayWrapper_set_FillPattern.argtypes=[c_void_p, c_int]
        CallCFunction(GetDllLibXls().InteriorArrayWrapper_set_FillPattern, self.Ptr, value.value)

    def BeginUpdate(self):
        """

        """
        GetDllLibXls().InteriorArrayWrapper_BeginUpdate.argtypes=[c_void_p]
        CallCFunction(GetDllLibXls().InteriorArrayWrapper_BeginUpdate, self.Ptr)

    def EndUpdate(self):
        """

        """
        GetDllLibXls().InteriorArrayWrapper_EndUpdate.argtypes=[c_void_p]
        CallCFunction(GetDllLibXls().InteriorArrayWrapper_EndUpdate, self.Ptr)
